summaryrefslogtreecommitdiffstats
path: root/src/os-plugins/plugins/xserver
diff options
context:
space:
mode:
authorDirk von Suchodoletz2011-05-25 15:45:29 +0200
committerDirk von Suchodoletz2011-05-25 15:45:29 +0200
commit5f11e7e2121dfbdd0b8d49ded7beb99c0c4ffdfc (patch)
treef13b6e466cdac2b07724af79bfa65c865ac1f976 /src/os-plugins/plugins/xserver
parentMore ... (diff)
downloadcore-5f11e7e2121dfbdd0b8d49ded7beb99c0c4ffdfc.tar.gz
core-5f11e7e2121dfbdd0b8d49ded7beb99c0c4ffdfc.tar.xz
core-5f11e7e2121dfbdd0b8d49ded7beb99c0c4ffdfc.zip
More Fedora stuff (unchanged mostly ...)
Diffstat (limited to 'src/os-plugins/plugins/xserver')
-rw-r--r--src/os-plugins/plugins/xserver/OpenSLX/Distro/Fedora.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/os-plugins/plugins/xserver/OpenSLX/Distro/Fedora.pm b/src/os-plugins/plugins/xserver/OpenSLX/Distro/Fedora.pm
index 13819059..6bfda47e 100644
--- a/src/os-plugins/plugins/xserver/OpenSLX/Distro/Fedora.pm
+++ b/src/os-plugins/plugins/xserver/OpenSLX/Distro/Fedora.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# xserver/OpenSLX/Distro/Suse.pm
# - provides SUSE-specific overrides of the Distro API for the xserver
# plugin.
# -----------------------------------------------------------------------------
-package xserver::OpenSLX::Distro::Suse;
+package xserver::OpenSLX::Distro::fedora;
use strict;
use warnings;
@@ -40,7 +40,7 @@ sub setupXserverScript
# add stuff to the script generated via Base.pm
$script .= unshiftHereDoc(<<' End-of-Here');
# SuSE specific extension to stage3 xserver.sh
testmkd /mnt/etc/X11/xorg.conf.d
# Add InputClass to proper setup the keyboard and other input
echo 'Section "InputClass"
@@ -80,7 +80,7 @@ sub setupXserverScript
testmkd /mnt/var/lib/X11
testmkd /mnt/var/lib/xdm/authdir/authfiles 0700
ln -s /usr/bin/Xorg /mnt/var/lib/X11/X
- rm /mnt/etc/X11/xdm/SuSEconfig.xdm
+ rm /mnt/etc/X11/xdm/fedoraconfig.xdm
End-of-Here
return $script;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# xserver/OpenSLX/Distro/Suse.pm
-# - provides SUSE-specific overrides of the Distro API for the xserver
+# xserver/OpenSLX/Distro/fedora.pm
+# - provides fedora-specific overrides of the Distro API for the xserver
# plugin.
# -----------------------------------------------------------------------------
@@ -40,7 +40,7 @@ sub setupXserverScript
# add stuff to the script generated via Base.pm
$script .= unshiftHereDoc(<<' End-of-Here');
- # SuSE specific extension to stage3 xserver.sh
+ # fedora specific extension to stage3 xserver.sh
testmkd /mnt/etc/X11/xorg.conf.d
# Add InputClass to proper setup the keyboard and other input